@@ -16,7 +16,7 @@ use Storable qw(store_fd retrieve_fd);
 
 our @ISA = qw(LWP::UserAgent);
 
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 
 
 
@@ -206,7 +206,6 @@ sub execute_method {
 
 }
 
-
 sub execute_request {
     my ($self, $request) = @_;
 
@@ -409,13 +408,16 @@ sub oauth_authorize_uri {
     my %args    = %{$self->{oauth}};
 
     $self->{oauth_request} = 'User Authentication';
-    $args{perms}           = $options->{perms} || 'read';
+    $args{perms}           = lc($options->{perms}) || 'read';
+
+    carp "\nThe 'perms' parameter must be one of: read, write, delete\n"
+        and return unless defined($args{perms}) && $args{perms} =~ /^(read|write|delete)$/;
 
     $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 
     return $self->{auth_uri} .
       '?oauth_token=' . $args{'request_token'}{'token'} .
-      '&perms=' . $args{'perms'};
+      '&perms=' . $args{perms};
 
 }
 
@@ -435,6 +437,11 @@ sub request_auth_url {
 
     }
 
+    $perms = lc($perms);
+
+    carp "\nThe 'perms' parameter must be one of: read, write, delete\n"
+        and return unless defined($perms) && $perms =~ /^(read|write|delete)$/;
+
     return undef unless defined $self->{api_secret} && length $self->{api_secret};
 
     my %args = (
@@ -806,6 +813,8 @@ if a secret was specified when creating the L<Flickr::API> object.
 Returns a L<URI> object representing the URL that an application must redirect a user to for approving
 an authentication token.
 
+C<$perms> must be B<read>, B<write>, or B<delete>.
+
 For web-based applications I<$frob> is an optional parameter.
 
 Returns undef if a secret was not specified when creating the C<Flickr::API> object.
@@ -988,7 +997,7 @@ a request token.
 
 =item C<perms>
 
-Permission the application is requesting, defaults to B<read>.
+Permission the application is requesting, one of B<read, write, or delete>, defaults to B<read>.
 
 =back
 
